@echo off
@setlocal
rem ============================================================================
rem @brief tweets.js を1000ツイート単位に分割する
rem
rem tweets.js が巨大だとツイート一括削除ツールが失敗する場合があるので
rem 1000個単位に分割するためのバッチファイル.
rem ツイートが多い場合は tweets.js だけでなく tweets-part0.js,  tweets-part1, ...
rem というファイルも存在する場合があるがフォーマットは同じなのでこのバッチで対応可能.
rem
rem 入力ファイル名に0000, 0001, 0002 のように連番を付加した出力ファイルを生成する.
rem 例
rem   入力ファイル tweets.js
rem   出力ファイル tweets-0000.js, tweets-0001.js, tweets-0002.js, ...
rem
rem 実行可能ファイル（.exe）は Ubuntu 上のMinGW でコンパイルした.
rem     $  x86_64-w64-mingw32-gcc -Wextra -Wall --std=c2x tweets-js-split.c -o tweets-js-split.exe && strip tweets-js-split.exe
rem 実行可能ファイルのライセンスは下記を参照すること.
rem COPYING.MinGW-w64-runtime.txt
rem
rem 個人が使うことを想定しているのでエラー処理などは特に行っていない.
rem
rem 免責事項
rem このファイルはパブリックドメインとします
rem このファイルは有用であることを期待していますがいかなる保証もありません。
rem すべての保証は明示的または黙示的にかかわらず放棄されるものとします。
rem
rem 参考
rem https://hangstuck.com/twitter-delete-all/
rem
rem @date 2023-03-04
rem @author hangstuck
rem @copyright Public Domain
rem ============================================================================

if "%1" == "" (
    call :usage
    pause > nul
    exit /b %ret_success%
)

echo %1 の分割を開始します

rem tweets.js をこのバッチファイルがあるフォルダにコピーする
rem 元ファイルをうっかり壊さないためと
rem .c 側でドライブレターの対応を入れるのが面倒なため
copy /Y %1 %~dp0
pushd %~dp0

%~n0.exe %~nx1
if errorlevel 1 (
   echo 分割に失敗しました. ERRORLEVEL : %ERRORLEVEL%.
   popd
   pause > nul
   exit /b %ERRORLEVEL%
)

popd
echo %1 の分割に成功しました
pause > nul

exit 0

:usage
echo tweets.js や tweets-part0.js などを1000個のツイートに分割するバッチファイルです
echo 分割後のファイル名は
echo tweets-0000.js,tweets-0001.js, tweets-0002.js, ...
echo のようになります。
echo [Usage]
echo %~n0 tweets.js


