/**
 * @brief tweets.js を1000ツイート単位に分割する
 *
 * 個人で使うことを想定しているのでセキュアなつくりにはなっていない.
 * 変なファイルを食わせるとどうなるかは想定していない.
 *
 * 免責事項
 * このファイルはパブリックドメインとします
 * このファイルは有用であることを期待していますがいかなる保証もありません。
 * すべての保証は明示的または黙示的にかかわらず放棄されるものとします。
 *
 * ライセンスは同梱の下記のファイルを参照すること
 * COPYING.MinGW-w64-runtime.txt
 *
 * 使用方法は同梱の bat ファイルの先頭コメントを参照すること.
 */
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <limits.h>

/* refs. https://hangstuck.com/cpp-debug-printf */
//#define DEBUG_BUILD
#ifdef DEBUG_BUILD
# define DEBUG_PRINTF(fmt, ...) (void) fprintf(stdout, "debug: file %s, func %s, line %d: " fmt, __FILE__, __func__, __LINE__, ## __VA_ARGS__);
#else
# define DEBUG_PRINTF(fmt, ...)
#endif

int main(int argc, const char *argv[])
{
    FILE *fp;
    FILE *out_fp;
    char out_fn[BUFSIZ] = {'\0'};
    char line_buff[BUFSIZ] = {'\0'};
    char first_line[BUFSIZ] = {'\0'};
    char tmp_buff[BUFSIZ] = {'\0'};
    int part_num = INT_MAX;
    int ret;
    unsigned int line_num = 0;
    unsigned int tweet_num = 0;
    unsigned int outfile_num = 0;
    static const int delete_tweet_num = 1000;

    DEBUG_PRINTF("start\n");
    DEBUG_PRINTF("argc %d.\n", argc);

    if (argc != 2) {
        (void) fprintf(stderr, "??? Invalid argument. \n");
        (void) fprintf(stderr, "usage: \n");
        (void) fprintf(stderr, " %s tweets.js\n", argv[0]);
        goto ERR;
    }
    DEBUG_PRINTF("argv[1] %s.\n", argv[1]);

    fp = fopen(argv[1], "r");
    if (!fp) {
        (void) fprintf(stderr, "??? ERROR: can not open %s.\n", argv[1]);
        goto ERR;
    }

    /*
     * tweets.js の最初の1行目は下記のようになっているはず.
     * window.YTD.tweets.part0 = [
     */
    if (!fgets(first_line, sizeof(first_line), fp)) {
        (void) fprintf(stderr, "??? ERROR: can not read %s.\n", argv[1]);
        goto ERR;
    }
    line_num++;

    ret = sscanf(first_line, "window.YTD.tweets.part%d %1[=] [", &part_num, tmp_buff);
    if (ret != 2 || ret == EOF) {
        (void) fprintf(stderr, "??? ERROR: unknown format, line %d, line_buff %s.\n", line_num, line_buff);
        goto ERR;
    }
    DEBUG_PRINTF("part_num %d\n", part_num);

    do {
        /* ./tweets.js のように指定されると動かない..... */
        if (1 != sscanf(argv[1], "%[^.]", out_fn)) {
            (void) fprintf(stderr, "??? ERROR: sscanf return error, %s.\n", argv[1]);
            goto ERR;
        }

        (void) sprintf(out_fn + strlen(out_fn), "-%04d.js", outfile_num);
        DEBUG_PRINTF("out_fn %s\n", out_fn);

        out_fp = fopen(out_fn, "w");
        if (!out_fp) {
            (void) fprintf(stderr, "??? ERROR: can not open %s.\n", out_fn);
            goto ERR;
        }
        (void) fprintf(out_fp, "%s", first_line);
        outfile_num++;

        while (fgets(line_buff, sizeof(line_buff), fp)) {
            if (!strcmp(line_buff, "  },\n") && 0 == ++tweet_num % delete_tweet_num) {
                (void) fprintf(out_fp, "  }\n" "]\n");
                break;
            }
            (void) fprintf(out_fp, "%s", line_buff);
        }
        fclose(out_fp);
    } while (strcmp(line_buff, "]\n") && strcmp(line_buff, "\n"));

    return 0;

ERR:
    DEBUG_PRINTF("ret %d\n", ret);
    return 1;
}
